﻿/*
Live Logger
Version:    1.0.2
Authors:    Ismail Mayat & Warren Buckley
*/


(function ($) {
    $.fn.outerHTML = function () {
        return $(this).clone().wrap('<div></div>').parent().html();
    };
})(jQuery);

//When DOM Ready
$(function () {
    //Setup Connection to signalR
    var liveLogger = $.connection.LiveLoggerHub;

    //Get the current value stored in the dropdown filter
    var currentFilter = $('#filter').val();

    //Update the hidden textbox with the updated table HTML
    $('#tableHtml').html($('#logTable').outerHTML());

    //When Log4Net (signalR hub) fires onLoggedEvent, call addRow() JS Function
    liveLogger.client.onLoggedEvent = addRow;

    //Fire up signalR and wait for calls
    $.connection.hub.start().done(function () {
        liveLogger.server.listen();
    });


    //Filtering - when dropdown changes...
    $('#filter').change(function () {
        //Get the current selected value in the filter dropdown
        var option = $('#filter').val();

        //Set currentFilter to the option value
        currentFilter = option;

        //If current filter = All
        if (currentFilter == "ALL") {

            //Show all table rows excluding first table row/header
            $('#logTable tr').not(':first').show();
        }
        else {
            //Otherwise...
            //Show all rows first, then refilter just in case we have already hidden stuff
            $('#logTable tr').not(':first').show();

            //For every tr that is not the first table row header
            //Where the tr has a td that contains the current filter value
            //Hide the parent element which is the tr
            $('#logTable tr').not(':first').not($('tr').find('td:contains(' + currentFilter + ')').parent()).hide();
        }

        //Update the hidden textbox with the updated table HTML
        $('#tableHtml').html($('#logTable').outerHTML());

        //For every tr that is not the first table row header
        //Where the tr has a td that contains the current filter value
        //Hide the parent element which is the tr
        $('#tableHtml tr').not(':first').not($('tr').find('td:contains(' + currentFilter + ')').parent()).hide();
    });


    //Modal Click (Bind data into the table)
    $('#logModal').on('show', function (e) {
        //Bind the items to the table...
        
        //Modal data
        var data = $(e.currentTarget).data('modal').options;
        console.log('Inserting data into modal');
        console.log(data);

        $('.log-domain').text(data.logDomain);
        $('.log-exception').text(data.logExceptionString);
        $('.log-class').text(data.logLocationClassName);
        $('.log-file').text(data.logLocationFileName);
        $('.log-fullinfo').text(data.logLocationFullInfo);
        $('.log-line').text(data.logLocationLineNumber);
        $('.log-method').text(data.logLocationMethodName);
        $('.log-logger').text(data.logLoggerName);
        $('.log-message').text(data.logMessage);
        $('.log-thread').text(data.logThreadName);
        $('.log-time').text(data.logTimeStamp);
        $('.log-user').text(data.logUsername);

    });

    //Modal When closed/hidden
    $('#logModal').on('hidden', function (e) {
        //Remove the data-bound items        
        console.log('Clearing out data in modal');

        $('.log-domain').text('');
        $('.log-exception').text('');
        $('.log-class').text('');
        $('.log-file').text('');
        $('.log-fullinfo').text('');
        $('.log-line').text('');
        $('.log-method').text('');
        $('.log-logger').text('');
        $('.log-message').text('');
        $('.log-thread').text('');
        $('.log-time').text('');
        $('.log-user').text('');

        //Remove the data in the modal object
        $(this).removeData('modal');
    });



    //When Log4Net fires, we call this function...
    function addRow(formattedEvent, loggedEvent) {

        //Get a bool to see if the pause checkbox is checked or not
        var paused = $('#pause').is(':checked');

        //if current filter = ALL OR log matches the filter in the dropdown
        //AND paused is not true
        if ((currentFilter == "ALL" || loggedEvent.Level.Name == currentFilter) && paused == false) {

            //Pass object to browser consle.log (for debugging)
            console.log(loggedEvent);

            //Thread cell
            var threadCell = $("<td>").css("white-space", "nowrap").text(loggedEvent.ThreadName);

            //Format DateTime
            var dt = moment(loggedEvent.TimeStamp, "YYYY-MM-DDTHH:mm:ss").format("DD/MM/YYYY @ HH:mm:ss");

            //Date Time Cell
            var dateCell = $("<td>").css("white-space", "nowrap").text(dt);

            //Logging Level Cell
            var levelCell = $("<td>").text(loggedEvent.Level.Name);

            //Details Cell
            var detailsCell = $("<td>").text(loggedEvent.Message);

            //View Log Button (with data attributes)
            var viewLogButton = "<a class='btn btn-info' data-toggle='modal' data-target='#logModal' \
                data-log-domain='" + loggedEvent.Domain + "' \
                data-log-exception-string='" + loggedEvent.ExceptionString + "' \
                data-log-location-class-name='" + loggedEvent.LocationInfo.ClassName + "' \
                data-log-location-file-name='" + loggedEvent.LocationInfo.FileName + "' \
                data-log-location-full-info='" + loggedEvent.LocationInfo.FullInfo + "' \
                data-log-location-line-number='" + loggedEvent.LocationInfo.LineNumber + "' \
                data-log-location-method-name='" + loggedEvent.LocationInfo.MethodName + "' \
                data-log-logger-name='" + loggedEvent.LoggerName + "' \
                data-log-message='" + loggedEvent.Message + "' \
                data-log-thread-name='" + loggedEvent.ThreadName + "' \
                data-log-time-stamp='" + dt + "' \
                data-log-username='" + loggedEvent.UserName + "'> \
                <i class='icon-info-sign icon-white'></i> View Log</a>";

            //View Log Cell
            var viewLogCell = $("<td>").html(viewLogButton);

            //Build up row
            var row = $("<tr class=\"" + loggedEvent.Level.Name.toString().toLocaleLowerCase() + "\">").append(threadCell, dateCell, levelCell, detailsCell, viewLogCell);
            $('#logTable tbody tr:first').after(row);


            //Update the hidden textbox with the updated table HTML
            $('#tableHtml').html($('#logTable').outerHTML());
        }
    }
});